=======
History
=======

0.1.0 (2018-06-12)
------------------

* First release on PyPI.

0.2.0 (2018-06-24)
------------------

* on error: optional function to be called if any of the environment tokens in value is not present in environment
* in self: optional variable name in case instance property is to be initialized
* package slightly restructured
